@@ -1,10 +1,11 @@
 
 /* LDAP posixAccount handler for Pure-FTPd */
-/* (C)opyleft 2001-2006 by Frank DENIS <j@pureftpd.org> */
+/* (C)opyleft 2001-2009 by Frank DENIS <j at pureftpd dot org> */
 
 #ifndef __LOG_LDAP_P_H__
 #define __LOG_LDAP_P_H__ 1
 
+#define LDAP_DEPRECATED 1
 #include <lber.h>
 #include <ldap.h>
 
@@ -22,6 +23,8 @@ static char *default_uid_s;
 static uid_t default_uid;
 static char *default_gid_s;
 static gid_t default_gid;
+static char *use_tls_s;
+static int use_tls;
 
 static ConfigKeywords ldap_config_keywords[] = {
     { "LDAPServer", &ldap_host },
@@ -34,6 +37,7 @@ static ConfigKeywords ldap_config_keywords[] = {
     { "LDAPVersion", &ldap_version_s },
     { "LDAPDefaultUID", &default_uid_s },
     { "LDAPDefaultGID", &default_gid_s },
+    { "LDAPUseTLS", &use_tls_s },
     { NULL, NULL }
 };
 
