@@ -16,7 +16,7 @@
 #define MSG_DEBUG_COMMAND "Command"
 #define MSG_IS_YOUR_CURRENT_LOCATION "is your current location"
 #define MSG_NOT_LOGGED_IN "You aren't logged in"
-#define MSG_AUTH_UNIMPLEMENTED "Security extensions not implemented"
+#define MSG_AUTH_UNIMPLEMENTED "This security scheme is not implemented"
 #define MSG_NO_FILE_NAME "No file name"
 #define MSG_NO_DIRECTORY_NAME "No directory name"
 #define MSG_NO_RESTART_POINT "No restart point"
@@ -44,7 +44,7 @@
 #define MSG_NO_PASSWORD_NEEDED "Any password will work"
 #define MSG_NOTRUST "Sorry, but I can't trust you"
 #define MSG_WHOAREYOU "Please tell me who you are"
-#define MSG_AUTH_FAILED "Authentication failed, sorry"
+#define MSG_AUTH_FAILED "Login authentication failed"
 #define MSG_AUTH_TOOMANY "Too many authentication failures"
 #define MSG_NO_HOMEDIR "Home directory not available - aborting"
 #define MSG_NO_HOMEDIR2 "%s does not exist or is unreachable"
@@ -173,18 +173,17 @@
 #define MSG_WELCOME_TO "Welcome to"
 #define MSG_MAX_USERS "%lu users (the maximum) are already logged in, sorry"
 #define MSG_NB_USERS "You are user number %d of %d allowed."
-#define MSG_WELCOME_TIME "Local time is now %02d:%02d and the load is %3.2f. Server port: %u."
+#define MSG_WELCOME_TIME "Local time is now %02d:%02d. Server port: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Only anonymous FTP is allowed here"
 #define MSG_RATIOS_EVERYONE "RATIOS ARE ENABLED FOR EVERYONE:"
 #define MSG_RATIOS_ANONYMOUS "ANONYMOUS USERS ARE SUBJECT TO AN UL/DL RATIO:"
 #define MSG_RATIOS_RULE "to download %u Mb, uploading %u Mb of goodies is mandatory."
 #define MSG_INFO_IDLE_M "You will be disconnected after %lu minutes of inactivity."
 #define MSG_INFO_IDLE_S "You will be disconnected after %lu seconds of inactivity."
-#define MSG_INFO_CPU_TIME "Logout - CPU time spent: %ld.%03ld seconds."
 #define MSG_CANT_READ_FILE "Sorry, we were unable to read [%s]"
 #define MSG_LS_TRUNCATED "Output truncated to %u matches"
 #define MSG_LS_SUCCESS "%u matches total"
-#define MSG_LOGOUT "Logout"
+#define MSG_LOGOUT "Logout."
 #define MSG_AUTH_FAILED_LOG "Authentication failed for user [%s]"
 #define MSG_ILLEGAL_UMASK "Invalid umask"
 #define MSG_STANDALONE_FAILED "Unable to start a standalone server"
@@ -215,3 +214,13 @@
 #define MSG_ALIASES_LIST "The following aliases are available :"
 #define MSG_PERUSER_MAX "I can't accept more than %lu connections as the same user"
 #define MSG_IPV6_OK "IPv6 connections are also welcome on this server."
+#define MSG_TLS_INFO "SSL/TLS: Enabled %s with %s, %d secret bits cipher"
+#define MSG_TLS_WEAK "SSL/TLS: Cipher too weak"
+#define MSG_TLS_NEEDED "Sorry, cleartext sessions are not accepted on this server.\n" \
+    "Please reconnect using SSL/TLS security mechanisms."
+#define MSG_ILLEGAL_CHARSET "Illegal charset"
+#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
+#define MSG_PROT_OK "Data protection level set to \"%s\""
+#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
+#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
+#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
