@@ -218,4 +218,9 @@
 #define MSG_TLS_WEAK "SSL/TLS: Criptografia muito fraca"
 #define MSG_TLS_NEEDED "Desculpe, sesses sem criptografia no so aceitas neste servidor.\n" \
     "Por favor reconecte-se usando mecanismos de segurana SSL/TLS."
-#define MSG_ILLEGAL_CHARSET "Illegal charset"
+#define MSG_ILLEGAL_CHARSET "Conjunto de caracteres ilegal"
+#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
+#define MSG_PROT_OK "Data protection level set to \"%s\""
+#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
+#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
+#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
