@@ -10,6 +10,8 @@
 int tls_init_library(void);
 void tls_free_library(void);
 int tls_init_new_session(void);
+int tls_init_data_session(int fd);
+void tls_close_session(SSL **cnx);
 
 # ifndef IN_TLS_C
 extern
@@ -21,6 +23,12 @@ extern
 # endif
     SSL *tls_cnx;
 
+# ifndef IN_TLS_C
+extern
+# endif
+    SSL *tls_data_cnx;
+
+
 /* If we really have to, use an insecure but exportable 512-bits key */
 # define RSA_EPHEMERAL_KEY_LEN 512
 
